package me.unurled.sacredrealms.sr.components.cutscene.tasks;

import static me.unurled.sacredrealms.sr.utils.Logger.error;
import static me.unurled.srcore.utils.Component.textComp;

import me.unurled.sacredrealms.sr.components.cutscene.Replay;
import me.unurled.sacredrealms.sr.components.cutscene.ReplayManager;
import me.unurled.sacredrealms.sr.components.cutscene.recording.Recordable;
import me.unurled.srcore.api.Manager;

public class ReplayTask implements Runnable {

  private final Replay replay;
  private final ReplayManager rm;
  private long currentTick = 0;

  public ReplayTask(Replay replay) {
    this.replay = replay;
    rm = Manager.getInstance(ReplayManager.class);
  }

  @Override
  public void run() {

    if (currentTick >= replay.recording().tickDuration()) {
      replay.viewer().sendMessage(textComp("<yellow>Replay has ended."));
      rm.stopReplay(replay);
      return;
    }
    // get all recordables for current tick
    var recordables = replay.recording().recordables().get(currentTick);

    try {
      if (recordables == null) {
        currentTick++;
        return;
      }

      for (Recordable r : recordables) {
        // figure out how to replay a recordable
        r.replay();
      }
    } catch (Exception e) {
      error("Tick: " + currentTick);
      error(e.getMessage());

    } finally {
      currentTick++;
    }
  }
}
